import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="hyrise",
    version="0.1.1",
    author="Gurasis Osahan",
    author_email="gurasis.osahan@phac-aspc.gc.ca",
    description="HIV Resistance Interpretation and Visualization System - A comprehensive tool for HIV drug resistance analysis and visualization",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/phac-nml/HyRISE",
    package_dir={"": "src"},
    include_package_data=True,
    packages=setuptools.find_packages(where="src"),
    package_data={"hyrise": ["hyrise.def", "HIVDB_9.8.xml", "core/assets/*"]},
    python_requires="<=3.11",
    install_requires=[
        "annotated-types>=0.7.0",
        "anyio>=4.9.0",
        "attrs>=25.3.0",
        "beautifulsoup4>=4.13.4",
        "bio>=1.7.1",
        "biopython>=1.85",
        "biothings-client>=0.4.1",
        "build>=1.2.2.post1",
        "certifi>=2025.1.31",
        "charset-normalizer>=3.4.1",
        "click>=8.1.8",
        "coloredlogs>=15.0.1",
        "colormath2>=3.0.3",
        "contourpy>=1.3.2",
        "coverage[toml]>=7.8.0",
        "cycler>=0.12.1",
        "exceptiongroup>=1.2.2",
        "fonttools>=4.57.0",
        "gprofiler-official>=1.0.0",
        "h11>=0.14.0",
        "httpcore>=1.0.8",
        "httpx>=0.28.1",
        "humanfriendly>=10.0",
        "humanize>=4.12.2",
        "idna>=3.10",
        "importlib-metadata>=8.6.1",
        "iniconfig>=2.1.0",
        "jinja2>=3.1.6",
        "jsonschema>=4.23.0",
        "jsonschema-specifications>=2024.10.1",
        "kaleido>=0.2.1",
        "kiwisolver>=1.4.8",
        "markdown>=3.8",
        "markdown-it-py>=3.0.0",
        "markupsafe>=3.0.2",
        "matplotlib>=3.10.1",
        "mdurl>=0.1.2",
        "multiqc>=1.28",
        "mygene>=3.2.2",
        "narwhals>=1.35.0",
        "natsort>=8.4.0",
        "networkx>=3.4.2",
        "numpy<2.0.0,>=1.24.3",
        "packaging>=25.0",
        "pandas>=2.2.3",
        "pillow>=11.2.1",
        "pip-tools>=7.4.1",
        "platformdirs>=4.3.7",
        "plotly>=6.0.1",
        "pluggy>=1.5.0",
        "poetry-core>=2.1.2",
        "pooch>=1.8.2",
        "pydantic>=2.11.3",
        "pydantic-core>=2.33.1",
        "pygments>=2.19.1",
        "pyparsing>=3.2.3",
        "pyproject-hooks>=1.2.0",
        "pytest>=8.3.5",
        "pytest-cov>=6.1.1",
        "python-dateutil>=2.9.0.post0",
        "python-dotenv>=1.1.0",
        "pytz>=2025.2",
        "pyyaml>=6.0.2",
        "referencing>=0.36.2",
        "regex>=2024.11.6",
        "requests>=2.32.3",
        "rich>=14.0.0",
        "rich-click>=1.8.8",
        "rpds-py>=0.24.0",
        "seaborn>=0.13.2",
        "six>=1.17.0",
        "sniffio>=1.3.1",
        "soupsieve>=2.7",
        "spectra>=0.1.0",
        "tabulate>=0.9.0",
        "tiktoken>=0.9.0",
        "tomli>=2.2.1",
        "tqdm>=4.67.1",
        "typeguard>=4.4.2",
        "typing-extensions>=4.13.2",
        "typing-inspection>=0.4.0",
        "tzdata>=2025.2",
        "urllib3>=2.4.0",
        "wheel>=0.45.1",
        "zipp>=3.21.0",
    ],
    entry_points={
        "console_scripts": [
            "hyrise=hyrise.cli:main",
            "hyrise-container-build=hyrise.commands.container:main",
            "hyrise-sierra=hyrise.commands.sierra:main",
        ]
    },
    keywords="hiv drug-resistance genomics bioinformatics visualization multiqc sierra hiv-sequence analysis mutation",
    license="GPL-3.0-or-later",
    project_urls={
        "Source": "https://github.com/phac-nml/HyRISE",
        "Tracker": "https://github.com/phac-nml/HyRISE/-/issues",
        "Documentation": "https://github.com/phac-nml/HyRISE/wiki",
        "Publication": "https://github.com/phac-nml/HyRISE#citation",
        "Contact": "https://github.com/phac-nml/HyRISE#contact",
    },
    classifiers=[
        "Development Status :: 4 - Beta",  # Changed from "1 - Beta" to standard "4 - Beta"
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Intended Audience :: Healthcare Industry",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        "Topic :: Scientific/Engineering :: Medical Science Apps.",
        "Topic :: Scientific/Engineering :: Information Analysis",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Distributed Computing",
        "Operating System :: OS Independent",
        "Operating System :: POSIX :: Linux",
        "Natural Language :: English",
        "Environment :: Console",
        "Framework :: Pytest",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
    ],
)
